@@ -1,6 +1,6 @@
 #---------------------------------
 # @author Bodo (Hugo) Barwich
-# @version 2023-09-23
+# @version 2023-10-07
 # @package SubProcess Management
 # @subpackage Process/SubProcess.pm
 
@@ -44,7 +44,7 @@ use IO::Select;
 use IPC::Open3;
 use Symbol qw(gensym);
 
-our $VERSION = '2.1.8';
+our $VERSION = '2.1.9';
 
 =head1 DESCRIPTION
 
@@ -460,6 +460,27 @@ sub setTimeout {
     }           #if(scalar(@_) > 1)
 }
 
+=pod
+
+=over 4
+
+=item setProfiling ( PROFILING )
+
+This method activated the B<Execution Time> measuring.
+
+It can only be set when the Sub Process is not running.
+
+B<Parameters:>
+
+C<PROFILING> - whole number to enable or disable the profiling. Negative numbers or C< 0 >
+will disable it. Positive numbers or C< 1 > will enable it.
+
+See L<Method C<Launch()>|/"Launch ()">
+
+=back
+
+=cut
+
 sub setProfiling {
     my $self = $_[0];
 
@@ -1438,6 +1459,85 @@ sub getProcessStatus {
     return $_[0]->{'_process_status'};
 }
 
+=pod
+
+=over 4
+
+=item getStartTime ()
+
+This method returns the B<Start Time>. The B<Start Time> is measured at the moment
+of the launch of the Sub Process.
+
+This feature has to be enabled with the C<setProfiling()> method.
+
+It has only a value after the Sub Process is launched.
+
+B<Returns:> It returns floating point number representing the time when the Sub Process
+was launched.
+
+See L<Method C<Launch()>|/"Launch ()">
+
+See L<Method C<setProfiling()>|/"setProfiling ( PROFILING )">
+
+=back
+
+=cut
+
+sub getStartTime {
+    return $_[0]->{'_start_time'};
+}
+
+=pod
+
+=over 4
+
+=item getEndTime ()
+
+This method returns the B<End Time>. The B<End Time> is measured at the moment
+when the Sub Process is detected as terminated.
+
+This feature has to be enabled with the C<setProfiling()> method.
+
+It has only a value after the Sub Process is terminated.
+
+B<Returns:> It returns floating point number representing the time when the Sub Process
+was terminated and reaped.
+
+See L<Method C<Launch()>|/"Launch ()">
+
+See L<Method C<setProfiling()>|/"setProfiling ( PROFILING )">
+
+=back
+
+=cut
+
+sub getEndTime {
+    return $_[0]->{'_end_time'};
+}
+
+=pod
+
+=over 4
+
+=item getExecutionTime ()
+
+This method returns the B<Execution Time>. The B<Execution Time> is the micro second
+precision time span between the launch of the Sub Process until its termination.
+
+This feature has to be enabled with the C<setProfiling()> method.
+
+It has only a value after the Sub Process is terminated.
+
+B<Returns:> It returns floating point number representing the B<Execution Time>.
+
+See L<Method C<Launch()>|/"Launch ()">
+
+See L<Method C<setProfiling()>|/"setProfiling ( PROFILING )">
+
+=back
+
+=cut
+
 sub getExecutionTime {
     return $_[0]->{'_execution_time'};
 }
